#!/bin/bash

# ============LICENSE_START=======================================================
#  Copyright (C) 2019 The Nordix Foundation. All rights reserved.
# ================================================================================
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# SPDX-License-Identifier: Apache-2.0
# ============LICENSE_END=========================================================

set -o nounset
set -o errexit
set -o pipefail

# ensure we are in job build WORKSPACE
cd "$WORKSPACE"

export DEBIAN_FRONTEND=noninteractive

# install dependencies
echo "Info: Install python3.6-minimal python3-distutils virtualenv using apt"
sudo apt update -q=3 > /dev/null 2>&1
sudo apt install -o Dpkg::Options::=--force-confdef -o Dpkg::Options::=--force-confnew -q=3 -y python3.6-minimal python3-distutils virtualenv > /dev/null 2>&1

# create and activate virtualenv
echo "Info: Create and activate python virtualenv"
virtualenv -p python3.6 .venv > /dev/null 2>&1
set +u
source .venv/bin/activate > /dev/null 2>&1
set -u

# install test-requirements
echo "Info: Install python packages listed in test-requirements.txt using pip"
pip install --force-reinstall --quiet -r test-requirements.txt > /dev/null 2>&1

# set default lint type
export LINT_TYPE="${LINT_TYPE:-ansible-lint}"

# run tox
echo "Info: Run $LINT_TYPE using tox"
echo "----------------------------------------------------"
tox -e "$LINT_TYPE"
echo "----------------------------------------------------"
echo "Info: Done!"

# vim: set ts=2 sw=2 expandtab:
